<?php
/**
 * Senior Care Lite functions and definitions
 *
 * @subpackage Senior Care Lite
 * @since 1.0
 */

//woocommerce//
//shop page no of columns
function senior_care_lite_woocommerce_loop_columns() {
	
	$retrun = get_theme_mod( 'senior_care_lite_archieve_item_columns', 3 );
    
    return $retrun;
}
add_filter( 'loop_shop_columns', 'senior_care_lite_woocommerce_loop_columns' );
function senior_care_lite_woocommerce_products_per_page() {

		$retrun = get_theme_mod( 'senior_care_lite_archieve_shop_perpage', 6 );
    
    return $retrun;
}
add_filter( 'loop_shop_per_page', 'senior_care_lite_woocommerce_products_per_page' );
// related products
function senior_care_lite_related_products_args( $args ) {
    $defaults = array(
        'posts_per_page' => get_theme_mod( 'senior_care_lite_related_shop_perpage', 3 ),
        'columns'        => get_theme_mod( 'senior_care_lite_related_item_columns', 3),
    );

    $args = wp_parse_args( $defaults, $args );

    return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'senior_care_lite_related_products_args' );
function senior_care_lite_related_products_heading($senior_care_lite_translated_text, $text, $domain) {
    $senior_care_lite_heading = get_theme_mod('woocommerce_related_products_heading', 'Related products');

    if ($text === 'Related products' && $domain === 'woocommerce') {
        $senior_care_lite_translated_text = $senior_care_lite_heading;
    }
    return $senior_care_lite_translated_text;
}
add_filter('gettext', 'senior_care_lite_related_products_heading', 20, 3);
// breadcrumb seperator
function senior_care_lite_woocommerce_breadcrumb_separator($senior_care_lite_defaults) {
    $senior_care_lite_separator = get_theme_mod('woocommerce_breadcrumb_separator', ' / ');

    // Update the separator
    $senior_care_lite_defaults['delimiter'] = $senior_care_lite_separator;

    return $senior_care_lite_defaults;
}
add_filter('woocommerce_breadcrumb_defaults', 'senior_care_lite_woocommerce_breadcrumb_separator');

//add animation class
if ( class_exists( 'WooCommerce' ) ) { 
	add_filter('post_class', function($senior_care_lite_classes, $class, $product_id) {
	    if( is_shop() || is_product_category() ){
	        
	        $senior_care_lite_classes = array_merge(['wow','swing'], $senior_care_lite_classes);
	    }
	    return $senior_care_lite_classes;
	},10,3);
}

//woocommerce-end//

// Get start function
function senior_care_lite_custom_admin_notice() {
    // Check if the notice is dismissed
    if (!get_user_meta(get_current_user_id(), 'dismissed_admin_notice', true)) {
        // Check if not on the theme documentation page
        $senior_care_lite_current_screen = get_current_screen();
        if ($senior_care_lite_current_screen && $senior_care_lite_current_screen->id !== 'appearance_page_senior-care-lite-guide-page') {
            $senior_care_lite_theme = wp_get_theme();
            ?>
            <div class="notice notice-info is-dismissible">
                <div class="notice-div">
                    <div>
                        <p class="theme-name"><?php echo esc_html($senior_care_lite_theme->get('Name')); ?></p>
                        <p><?php _e('For information and detailed instructions, check out our theme documentation.', 'senior-care-lite'); ?></p>
                    </div>
                    <a class="button-primary" href="themes.php?page=senior-care-lite-guide-page"><?php _e('Theme Documentation', 'senior-care-lite'); ?></a>
                </div>
            </div>
        <?php
        }
    }
}
add_action('admin_notices', 'senior_care_lite_custom_admin_notice');
// Dismiss notice function
function senior_care_lite_dismiss_admin_notice() {
    update_user_meta(get_current_user_id(), 'dismissed_admin_notice', true);
}
add_action('wp_ajax_senior_care_lite_dismiss_admin_notice', 'senior_care_lite_dismiss_admin_notice');
// Enqueue scripts and styles
function senior_care_lite_enqueue_admin_script($hook) {
    // Admin JS
    wp_enqueue_script('senior-care-lite-admin.js', get_theme_file_uri('/assets/js/senior-care-lite-admin.js'), array('jquery'), true);

    wp_localize_script('senior-care-lite-admin.js', 'senior_care_lite_scripts_localize', array(
        'ajax_url' => esc_url(admin_url('admin-ajax.php'))
    ));
}
add_action('admin_enqueue_scripts', 'senior_care_lite_enqueue_admin_script');
// Reset the dismissed notice status when the theme is switched
function senior_care_lite_after_switch_theme() {
    delete_user_meta(get_current_user_id(), 'dismissed_admin_notice');
}
add_action('after_switch_theme', 'senior_care_lite_after_switch_theme');
//get-start-function-end//

// tag count
function senior_care_lite_display_post_tag_count() {
    $senior_care_lite_tags = get_the_tags();
    $senior_care_lite_tag_count = ($senior_care_lite_tags) ? count($senior_care_lite_tags) : 0;
    $senior_care_lite_tag_text = ($senior_care_lite_tag_count === 1) ? 'tag' : 'tags';
    echo $senior_care_lite_tag_count . ' ' . $senior_care_lite_tag_text;
}

//media post format
function senior_care_lite_get_media($senior_care_lite_type = array()){
	$senior_care_lite_content = apply_filters( 'the_content', get_the_content() );
  	$output = false;

  // Only get media from the content if a playlist isn't present.
  if ( false === strpos( $senior_care_lite_content, 'wp-playlist-script' ) ) {
    $output = get_media_embedded_in_content( $senior_care_lite_content, $senior_care_lite_type );
    return $output;
  }
}

// front page template
function senior_care_lite_front_page_template( $template ) {
	return is_home() ? '' : $template;
}
add_filter( 'frontpage_template',  'senior_care_lite_front_page_template' );

// excerpt function
function senior_care_lite_custom_excerpt() {
    $senior_care_lite_excerpt = get_the_excerpt();
    $senior_care_lite_plain_text_excerpt = wp_strip_all_tags($senior_care_lite_excerpt);
    
    // Get dynamic word limit from theme mod
    $senior_care_lite_word_limit = esc_attr(get_theme_mod('senior_care_lite_post_excerpt', '30'));
    
    // Limit the number of words
    $senior_care_lite_limited_excerpt = implode(' ', array_slice(explode(' ', $senior_care_lite_plain_text_excerpt), 0, $senior_care_lite_word_limit));

    echo esc_html($senior_care_lite_limited_excerpt);
}

//typography
function senior_care_lite_fonts_scripts() {
	$headings_font = esc_html(get_theme_mod('senior_care_lite_headings_text'));
	$body_font = esc_html(get_theme_mod('senior_care_lite_body_text'));

	if( $headings_font ) {
		wp_enqueue_style( 'senior-care-lite-headings-fonts', '//fonts.googleapis.com/css?family='. $headings_font );
	} else {
		wp_enqueue_style( 'senior-care-lite-playfair-sans', '//fonts.googleapis.com/css?family=Playfair Display:ital,wght@0,400;0,500;0,600;0,700;0,800;0,900;1,400;1,500;1,600;1,700;1,800;1,900');
	}
	if( $body_font ) {
		wp_enqueue_style( 'senior-care-lite-body-fonts', '//fonts.googleapis.com/css?family='. $body_font );
	} else {
		wp_enqueue_style( 'senior-care-lite-jost-body', '//fonts.googleapis.com/css?family=Jost:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900');
	}
}
add_action( 'wp_enqueue_scripts', 'senior_care_lite_fonts_scripts' );

// Footer Text
function senior_care_lite_copyright_link() {
    $senior_care_lite_footer_text = get_theme_mod('senior_care_lite_footer_text', esc_html__('Senior Care WordPress Theme', 'senior-care-lite'));
    $senior_care_lite_credit_link = esc_url('https://www.ovationthemes.com/wordpress/free-senior-care-wordpress-theme/');

    echo '<a href="' . $senior_care_lite_credit_link . '" target="_blank">' . esc_html($senior_care_lite_footer_text) . '<span class="footer-copyright">' . esc_html__(' By Ovation Themes', 'senior-care-lite') . '</span></a>';
}

// custom sanitizations
// dropdown
function senior_care_lite_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}
// slider custom control
if ( ! function_exists( 'senior_care_lite_sanitize_integer' ) ) {
	function senior_care_lite_sanitize_integer( $input ) {
		return (int) $input;
	}
}
// range contol
function senior_care_lite_sanitize_number_absint( $number, $setting ) {

	// Ensure input is an absolute integer.
	$number = absint( $number );

	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;

	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );

	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );

	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}
// select post page
function senior_care_lite_sanitize_select( $input, $setting ){
    $input = sanitize_key($input);
    $choices = $setting->manager->get_control( $setting->id )->choices;
    return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}
// toggle switch
function senior_care_lite_callback_sanitize_switch( $value ) {
	// Switch values must be equal to 1 of off. Off is indicator and should not be translated.
	return ( ( isset( $value ) && $value == 1 ) ? 1 : 'off' );
}
//choices control
function senior_care_lite_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}
// Sanitize Sortable control.
function senior_care_lite_sanitize_sortable( $val, $setting ) {
	if ( is_string( $val ) || is_numeric( $val ) ) {
		return array(
			esc_attr( $val ),
		);
	}
	$sanitized_value = array();
	foreach ( $val as $item ) {
		if ( isset( $setting->manager->get_control( $setting->id )->choices[ $item ] ) ) {
			$sanitized_value[] = esc_attr( $item );
		}
	}
	return $sanitized_value;
}

// Customiser Sections Dropdown
function senior_care_lite_slider_dropdown(){
	if(get_option('senior_care_lite_slider_arrows') == true ) {
		return true;
	}
	return false;
}
function senior_care_lite_hide_show_dropdown(){
	if(get_option('senior_care_lite_hide_show_support') == true ) {
		return true;
	}
	return false;
}
function senior_care_lite_mission_dropdown(){
	if(get_option('senior_care_lite_mission_show_hide') == true ) {
		return true;
	}
	return false;
}

// theme setup
function senior_care_lite_setup() {
	add_theme_support( 'woocommerce' );
	add_theme_support( "align-wide" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( 'title-tag' );
	add_theme_support( "custom-header" );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'senior-care-lite-featured-image', 2000, 1200, true );
	add_image_size( 'senior-care-lite-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'senior-care-lite' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
		'flex-height'  => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio','quote',) );
	
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style( array( 'assets/css/editor-style.css', senior_care_lite_fonts_url() ) );
}
add_action( 'after_setup_theme', 'senior_care_lite_setup' );

// widgets
function senior_care_lite_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'senior-care-lite' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'senior-care-lite' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'senior-care-lite' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'senior-care-lite' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'senior-care-lite' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'senior-care-lite' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'senior-care-lite' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'senior-care-lite' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'senior-care-lite' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'senior-care-lite' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'senior-care-lite' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'senior-care-lite' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'senior-care-lite' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'senior-care-lite' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'senior_care_lite_widgets_init' );

// fonts
function senior_care_lite_fonts_url(){
	$font_url = '';
	$font_family = array();
	$font_family[] = 'Nunito Sans:ital,wght@0,200;0,300;0,400;0,600;0,700;0,800;0,900;1,200;1,300;1,400;1,600;1,700;1,800;1,900';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
	$contents = wptt_get_webfont_url( esc_url_raw( $fonts_url ) );
}

//Enqueue scripts and styles.
function senior_care_lite_scripts() {

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'senior-care-lite-fonts', senior_care_lite_fonts_url(), array(), null );

	//Bootstarp
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri().'/assets/css/bootstrap.css' );

	// Theme stylesheet.
	wp_enqueue_style( 'senior-care-lite-style', get_stylesheet_uri() );

	wp_style_add_data( 'senior-care-lite-style', 'rtl', 'replace' );

	// Theme Customize CSS.
	require get_parent_theme_file_path( 'inc/extra_customization.php' );
	wp_add_inline_style( 'senior-care-lite-style',$senior_care_lite_custom_style );

	//font-awesome
	wp_enqueue_style( 'font-awesome-style', get_template_directory_uri().'/assets/css/fontawesome-all.css' );

	// Block Style
	wp_enqueue_style( 'senior-care-lite-block-style', esc_url( get_template_directory_uri() ).'/assets/css/blocks.css' );

	//Custom JS
	wp_enqueue_script( 'senior-care-lite-custom.js', get_theme_file_uri( '/assets/js/theme-script.js' ), array( 'jquery' ), true );

	//Nav Focus JS
	wp_enqueue_script( 'senior-care-lite-navigation-focus', get_theme_file_uri( '/assets/js/navigation-focus.js' ), array( 'jquery' ), true );

	//Bootstarp JS
	wp_enqueue_script( 'bootstrap-js', get_theme_file_uri( '/assets/js/bootstrap.js' ), array( 'jquery' ),true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if (get_option('senior_care_lite_animation_enable', false) !== 'off') {
		//wow.js
		wp_enqueue_script( 'senior-care-lite-wow-js', get_theme_file_uri( '/assets/js/wow.js' ), array( 'jquery' ), true );

		//animate.css
		wp_enqueue_style( 'senior-care-lite-animate-css', get_template_directory_uri().'/assets/css/animate.css' );
	}
}
add_action( 'wp_enqueue_scripts', 'senior_care_lite_scripts' );

// Enqueue editor styles for Gutenberg
function senior_care_lite_block_editor_styles() {
	// Block styles.
	wp_enqueue_style( 'senior-care-lite-block-editor-style', trailingslashit( esc_url ( get_template_directory_uri() ) ) . '/assets/css/editor-blocks.css' );

	// Add custom fonts.
	wp_enqueue_style( 'senior-care-lite-fonts', senior_care_lite_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'senior_care_lite_block_editor_styles' );

# Load scripts and styles.(fontawesome)
add_action( 'customize_controls_enqueue_scripts', 'senior_care_lite_customize_controls_register_scripts' );
function senior_care_lite_customize_controls_register_scripts() {
	
	wp_enqueue_style( 'senior-care-lite-ctypo-customize-controls-style', trailingslashit( esc_url(get_template_directory_uri()) ) . '/assets/css/customize-controls.css' );
}

// enque files
require get_parent_theme_file_path( '/inc/custom-header.php' );
require get_parent_theme_file_path( '/inc/template-tags.php' );
require get_parent_theme_file_path( '/inc/template-functions.php' );
require get_parent_theme_file_path( '/inc/customizer.php' );
require get_parent_theme_file_path( '/inc/typography.php' );
require get_parent_theme_file_path( '/inc/dashboard/dashboard.php' );
require get_parent_theme_file_path('/inc/wptt-webfont-loader.php' );
require get_parent_theme_file_path( '/inc/breadcrumb.php' );
require get_parent_theme_file_path( 'inc/sortable/sortable_control.php' );